@@ -57,6 +57,7 @@ void mysql_statement_backend::prepare(std::string const & query,
     std::string name;
     queryChunks_.push_back("");
 
+    bool escaped = false;
     for (std::string::const_iterator it = query.begin(), end = query.end();
          it != end; ++it)
     {
@@ -70,7 +71,18 @@ void mysql_statement_backend::prepare(std::string const & query,
             }
             else if (*it == ':')
             {
-                state = eInName;
+                const std::string::const_iterator next_it = it + 1;
+                // Check whether this is an assignment (e.g. @x:=y)
+                // and treat it as a special case, not as a named binding.
+                if (next_it != end && *next_it == '=')
+                {
+                    queryChunks_.back() += ":=";
+                    ++it;
+                }
+                else
+                {
+                    state = eInName;
+                }
             }
             else // regular character, stay in the same state
             {
@@ -78,7 +90,7 @@ void mysql_statement_backend::prepare(std::string const & query,
             }
             break;
         case eInQuotes:
-            if (*it == '\'')
+            if (*it == '\'' && !escaped)
             {
                 queryChunks_.back() += *it;
                 state = eNormal;
@@ -87,6 +99,7 @@ void mysql_statement_backend::prepare(std::string const & query,
             {
                 queryChunks_.back() += *it;
             }
+            escaped = *it == '\\' && !escaped;
             break;
         case eInName:
             if (std::isalnum(*it) || *it == '_')
