@@ -45,9 +45,3 @@ once_temp_type & once_temp_type::operator,(into_type_ptr const & i)
     rcst_->exchange(i);
     return *this;
 }
-
-once_temp_type & once_temp_type::operator,(use_type_ptr const & u)
-{
-    rcst_->exchange(u);
-    return *this;
-}
