@@ -20,18 +20,16 @@
 
 // Define if you have the vsnprintf variants.
 #if _MSC_VER < 1500
-# define HAVE_VSNPRINTF 1
 # define vsnprintf _vsnprintf
 #endif
 
 // Define if you have the snprintf variants.
-#define HAVE_SNPRINTF 1
 #define snprintf _snprintf
 
 // Define if you have the strtoll and strtoull variants.
-#if _MSC_VER >= 1300
-# define HAVE_STRTOLL 1
-# define HAVE_STRTOULL 1
+#if _MSC_VER < 1300
+# error "Visual C++ versions prior 1300 don't support _strtoi64 and _strtoui64"
+#elif _MSC_VER >= 1300 && _MSC_VER < 1800
 namespace std {
     inline long long strtoll(char const* str, char** str_end, int base)
     {
@@ -43,11 +41,15 @@ namespace std {
         return _strtoui64(str, str_end, base);
     }
 }
-#else
-# undef HAVE_STRTOLL
-# undef HAVE_STRTOULL
-# error "Visual C++ versions prior 1300 don't support _strtoi64 and _strtoui64"
-#endif // _MSC_VER >= 1300
+#endif // _MSC_VER < 1800
 #endif // _MSC_VER
 
+#if defined(__CYGWIN__) || defined(__MINGW32__)
+#include <stdlib.h>
+namespace std {
+    using ::strtoll;
+    using ::strtoull;
+}
+#endif
+
 #endif // SOCI_PLATFORM_H_INCLUDED
